@@ -8,6 +8,7 @@ import zipfile
 from datetime import datetime
 from functools import lru_cache
 
+from django.conf import settings
 from django.db.models import Max
 from django.db.models.functions import Length
 
@@ -95,6 +96,11 @@ def export_insurees(batch=None, amount=None, dry_run=False):
         with open(csv_file_path, 'w') as f:
             # create the csv writer
             writer = csv.writer(f)
+            writer.writerow([
+                "InsureeNum", "OtherNames", "LastName", "DateOfBirth", "Gender", "Phone", "EffectiveDate",
+                "ValidityDate", "VillageCode", "VillageName", "WardCode", "WardName", "DistrictCode", "DistrictName",
+                "RegionCode", "RegionName",
+            ])
             files_to_zip = [(csv_file_path, "index.csv")]
             zip_file_path = tempfile.NamedTemporaryFile("wb", prefix="insuree_export", suffix=".zip", delete=False)
 
@@ -104,12 +110,37 @@ def export_insurees(batch=None, amount=None, dry_run=False):
                     files_to_zip.append((photo_filename, f"{insuree.chf_id}.jpg"))
                 else:
                     photo_filename = None
+                from core import datetimedelta
+                latest_policy = insuree\
+                    .insuree_policies\
+                    .filter(validity_to__isnull=True)\
+                    .order_by("-effective_date")\
+                    .first()
+                village = insuree.family.location
+                ward = village.parent if village else None
+                district = ward.parent if ward else None
+                region = district.parent if district else None
+
+                # TODO Make the validity and date formats configurable
                 writer.writerow([
                     insuree.chf_id,
                     insuree.other_names,
                     insuree.last_name,
-                    insuree.dob,
+                    insuree.dob.strftime('%d/%m/%Y') if insuree.dob else None,
                     insuree.gender_id,
+                    insuree.phone,
+                    latest_policy.effective_date.strftime('%d/%m/%Y')
+                    if latest_policy and latest_policy.effective_date else None,
+                    (latest_policy.effective_date + datetimedelta(years=2)).strftime('%d/%m/%Y')
+                    if latest_policy and latest_policy.effective_date else None,
+                    village.code,
+                    village.name,
+                    ward.code,
+                    ward.name,
+                    district.code,
+                    district.name,
+                    region.code,
+                    region.name,
                 ])
 
                 if photo_filename:
@@ -132,15 +163,22 @@ def export_insurees(batch=None, amount=None, dry_run=False):
 
 def get_insurees_to_export(batch, amount):
     # Since there is no foreign key from the batch to insuree, Django refuses to make a join or subquery 🤷🏻‍
-    # TODO make this DB independent, (TOP %s is SQL Server only)
-    sql = "select " + (f"TOP {int(amount)}" if amount else "") + " tblInsuree.* " \
-          "from tblInsuree " \
-          "inner join insuree_batch_batchinsureenumber ibb on tblInsuree.CHFID = ibb.CHFID " \
-          "where ibb.print_date is null"
+    if hasattr(settings, "DB_ENGINE") and "postgres" in settings.DB_ENGINE:
+        engine = "postgres"
+    else:
+        engine = "mssql"
+    sql = 'select ' + (f"TOP {int(amount)}" if amount and engine == "mssql" else "") + \
+          ' "tblInsuree".* ' \
+          'from "tblInsuree" ' \
+          'inner join insuree_batch_batchinsureenumber ibb on "tblInsuree"."CHFID" = ibb."CHFID" ' \
+          'where ibb.print_date is null '
     params = []
     if batch:
         sql = sql + " and ibb.batch_id=%s"
         params.append(str(batch.id).replace("-", ""))
 
+    if amount and engine == "postgres":
+        sql += f" LIMIT {int(amount)}"
+
     queryset = Insuree.objects.raw(sql, params)
     return queryset
